.. _module-docs:

Modules Reference
=================

.. module:: diofant

Because every feature of Diofant must have a test case, when you are not sure how
to use something, just look into the ``tests/`` directories, find that feature
and read the tests for it, that will tell you everything you need to know.

Most of the things are already documented though in this document, that is
automatically generated using Diofant's docstrings.

Click the  "modules" (:ref:`modindex`) link in the top right corner to easily
access any Diofant module, or use this contents:

.. toctree::
   :maxdepth: 2

   core
   combinatorics/index
   ntheory
   concrete
   functions/index
   geometry/index
   integrals
   logic
   domains
   matrices/index
   polys/index
   printing
   interactive
   plotting
   series
   sets
   simplify/simplify
   stats
   solvers/index
   tensor/index
   utilities/index
   parsing
   calculus/index
   diffgeom
   vector/index
